Fixed Menu Example - Semantic

Project Name Home
Dropdown
Link Item Link Item
Header Item
Sub Menu
Link Item Link Item
Link Item

# Semantic UI Fixed Template

This is a basic fixed menu template using fixed size containers.

A text container is used for the main container, which is useful for single column layouts

#### Group 1

Link One Link Two Link Three Link Four

#### Group 2

Link One Link Two Link Three Link Four

#### Group 3

Link One Link Two Link Three Link Four

#### Footer Header

Extra space for a call to action inside the footer that could help re-engage users.

Site Map Contact Us Terms and Conditions Privacy Policy